"""

    Removes virtualenv using pyenv if specified in the config file

    """

import subprocess
import sys
from pathlib import Path

from .util import Conf
from .util import read_json

c = Conf()

def rm_venv(fp) :
    j = read_json(fp)
    
    if j[c.rm_venv] :
        cmds = ['pyenv' , 'virtualenv-delete' , '-f' , Path(fp).stem]
        cmds += ['&> /dev/null']

        subprocess.run(cmds)

if __name__ == '__main__' :
    conf_fn = sys.argv[1]
    rm_venv(conf_fn)



import json
from pathlib import Path

from os import environ

class Conf :
    pkg = 'pip_pkg'
    py_ver = 'py_ver'  # python version to use
    module = "module"  # module name to run
    rm_venv = 'rm_venv'  # whether to remove venv after running

class Const :
    rc = Path(environ['HOME']) / 'auto_run_configs'

c = Const()

def read_json(fp) :
    # if fp is not entered with .json extension, add .json to it
    fp = fp.with_suffix('.json')

    fp = c.rc / fp

    with open(fp , 'r') as f :
        return json.load(f)



"""

    1. Installs the required python version, skips if already installed
    2. Creates a virtual environment with that python version

    """

import subprocess
import sys
from pathlib import Path

from .util import Conf
from .util import read_json

c = Conf()

def make_venv(fp) :
    j = read_json(fp)

    py_ver = j[c.py_ver]

    venv_name = Path(fp).stem

    _cmds = ['pyenv' , 'install' , '--skip-existing' , py_ver]
    subprocess.run(_cmds)

    _cmds = ['pyenv' , 'virtualenv' , py_ver , venv_name , '&> /dev/null']
    subprocess.run(_cmds)

    print(venv_name)

if __name__ == '__main__' :
    conf_fn = sys.argv[1]
    make_venv(conf_fn)



"""

    return relative command to run module

    """

import sys

from .util import Conf
from .util import read_json

c = Conf()

def ret_module_2_run_rel_command(fp) :
    j = read_json(fp)
    print(j[c.pkg] + '.' + j[c.module])

if __name__ == '__main__' :
    conf_fn = sys.argv[1]
    ret_module_2_run_rel_command(conf_fn)
